<p>
<center>
<img width=500 src="https://github.com/ChaitanyaChawak/chicagogogo/blob/main/chicagogogo/logo.png?raw=true"></img>
</center>

# chicagogogo
Like many other cities around the world, Chicago is a city built on a grid system. Unfortunately, many suburbs of Chicago, including Evanston (as well as the rest of the world) do not subscribe to this way to map the world. With Chicagogogo, we make a quick and easy-to-use package that will give you the number of blocks away from a given address-- the corner of State St and Madison St, the center of the downtown Loop and the center of Chicago! It can also give you the address of a location given the number of blocks away from the center of Chicago. 

Additionally, chicagogogo offers functions that can provide the latitude and longitude of any location globally and their precise location. This relies on funcionality from `Nominatim`, which is installed with your installation of `chicagogogo`.

# Installation Instructions:

`pip install chicagogogo`

`cd ./chicagogogo`

`python main.py`

This will cause Chicagogogo to start running on your machine.
# How To Use
Upon a successful startup, Chicagogogo will give you a question asking you whether you want to input a location, resulting in the code giving its location relative to downtown in blocks, or whether you want to input a set amount of blocks away from the loop, resulting in the code giving an address.

For the first case, respond `blocks`, and for the second case, respond `address`. From there, you will be directed through the packkage.
<p>
<left>
<img width=100 src="https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg"></img>
</left>
